@@ -7,29 +7,34 @@ namespace Drupal\Tests\Core\Database;
 use Drupal\Core\Database\Database;
 use Drupal\Core\Extension\Exception\UnknownExtensionException;
 use Drupal\Tests\UnitTestCase;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
+use PHPUnit\Framework\Attributes\PreserveGlobalState;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
+// cspell:ignore dummydb
 /**
  * Tests for database URL to/from database connection array conversions.
  *
  * These tests run in isolation since we don't want the database static to
  * affect other tests.
- *
- * @coversDefaultClass \Drupal\Core\Database\Database
- *
- * @runTestsInSeparateProcesses
- * @preserveGlobalState disabled
- *
- * @group Database
  */
+#[CoversClass(Database::class)]
+#[Group('Database')]
+#[PreserveGlobalState(FALSE)]
+#[RunTestsInSeparateProcesses]
 class UrlConversionTest extends UnitTestCase {
 
   /**
-   * @covers ::convertDbUrlToConnectionInfo
+   * Tests db url to connection conversion.
    *
-   * @dataProvider providerConvertDbUrlToConnectionInfo
+   * @legacy-covers ::convertDbUrlToConnectionInfo
    */
+  #[DataProvider('providerConvertDbUrlToConnectionInfo')]
   public function testDbUrlToConnectionConversion($url, $database_array, $include_test_drivers): void {
-    $result = Database::convertDbUrlToConnectionInfo($url, $this->root, $include_test_drivers);
+    $result = Database::convertDbUrlToConnectionInfo($url, $include_test_drivers);
     $this->assertEquals($database_array, $result);
   }
 
@@ -41,7 +46,7 @@ class UrlConversionTest extends UnitTestCase {
    *   - url: The full URL string to be tested.
    *   - database_array: An array containing the expected results.
    */
-  public static function providerConvertDbUrlToConnectionInfo() {
+  public static function providerConvertDbUrlToConnectionInfo(): array {
     return [
       'MySql without prefix' => [
         'mysql://test_user:test_pass@test_host:3306/test_database',
@@ -274,13 +279,12 @@ class UrlConversionTest extends UnitTestCase {
 
   /**
    * Tests ::convertDbUrlToConnectionInfo() exception for invalid arguments.
-   *
-   * @dataProvider providerInvalidArgumentsUrlConversion
    */
-  public function testGetInvalidArgumentExceptionInUrlConversion($url, $root, $expected_exception_message): void {
+  #[DataProvider('providerInvalidArgumentsUrlConversion')]
+  public function testGetInvalidArgumentExceptionInUrlConversion($url, $expected_exception_message): void {
     $this->expectException(\InvalidArgumentException::class);
     $this->expectExceptionMessage($expected_exception_message);
-    Database::convertDbUrlToConnectionInfo($url, $root);
+    Database::convertDbUrlToConnectionInfo($url);
   }
 
   /**
@@ -289,26 +293,45 @@ class UrlConversionTest extends UnitTestCase {
    * @return array
    *   Array of arrays with the following elements:
    *   - An invalid URL string.
-   *   - Drupal root string.
    *   - The expected exception message.
    */
-  public static function providerInvalidArgumentsUrlConversion() {
+  public static function providerInvalidArgumentsUrlConversion(): array {
     return [
-      ['foo', '', "Missing scheme in URL 'foo'"],
-      ['foo', 'bar', "Missing scheme in URL 'foo'"],
-      ['foo://', 'bar', "Can not convert 'foo://' to a database connection, the module providing the driver 'foo' is not specified"],
-      ['foo://bar', 'baz', "Can not convert 'foo://bar' to a database connection, the module providing the driver 'foo' is not specified"],
-      ['foo://bar:port', 'baz', "Can not convert 'foo://bar:port' to a database connection, the module providing the driver 'foo' is not specified"],
-      ['foo/bar/baz', 'bar2', "Missing scheme in URL 'foo/bar/baz'"],
-      ['foo://bar:baz@test1', 'test2', "Can not convert 'foo://bar:baz@test1' to a database connection, the module providing the driver 'foo' is not specified"],
+      ['foo', "Missing scheme in URL 'foo'"],
+      ['foo/bar/baz', "Missing scheme in URL 'foo/bar/baz'"],
     ];
   }
 
   /**
-   * @covers ::getConnectionInfoAsUrl
-   *
-   * @dataProvider providerGetConnectionInfoAsUrl
+   * Tests that connection URL with no module name defaults to driver name.
    */
+  public function testNoModuleSpecifiedDefaultsToDriverName(): void {
+    $url = 'dummydb://test_user:test_pass@test_host/test_database';
+    $connection_info = Database::convertDbUrlToConnectionInfo($url, TRUE);
+    $expected = [
+      'driver' => 'dummydb',
+      'username' => 'test_user',
+      'password' => 'test_pass',
+      'host' => 'test_host',
+      'database' => 'test_database',
+      'namespace' => 'Drupal\dummydb\Driver\Database\dummydb',
+      'autoload' => 'core/modules/system/tests/modules/dummydb/src/Driver/Database/dummydb/',
+      'dependencies' => [
+        'mysql' => [
+          'namespace' => 'Drupal\mysql',
+          'autoload' => 'core/modules/mysql/src/',
+        ],
+      ],
+    ];
+    $this->assertSame($expected, $connection_info);
+  }
+
+  /**
+   * Tests get connection info as url.
+   *
+   * @legacy-covers ::getConnectionInfoAsUrl
+   */
+  #[DataProvider('providerGetConnectionInfoAsUrl')]
   public function testGetConnectionInfoAsUrl(array $info, $expected_url): void {
     Database::addConnectionInfo('default', 'default', $info);
     $url = Database::getConnectionInfoAsUrl();
@@ -324,7 +347,7 @@ class UrlConversionTest extends UnitTestCase {
    *     database, username, password, prefix, host, port, namespace and driver.
    *   - The expected URL after conversion.
    */
-  public static function providerGetConnectionInfoAsUrl() {
+  public static function providerGetConnectionInfoAsUrl(): array {
     $info1 = [
       'database' => 'test_database',
       'username' => 'test_user',
@@ -451,20 +474,19 @@ class UrlConversionTest extends UnitTestCase {
   /**
    * Tests ::getConnectionInfoAsUrl() exception for invalid arguments.
    *
-   * @covers ::getConnectionInfoAsUrl
-   *
    * @param array $connection_options
    *   The database connection information.
    * @param string $expected_exception_message
    *   The expected exception message.
    *
-   * @dataProvider providerInvalidArgumentGetConnectionInfoAsUrl
+   * @legacy-covers ::getConnectionInfoAsUrl
    */
+  #[DataProvider('providerInvalidArgumentGetConnectionInfoAsUrl')]
   public function testGetInvalidArgumentGetConnectionInfoAsUrl(array $connection_options, $expected_exception_message): void {
     Database::addConnectionInfo('default', 'default', $connection_options);
     $this->expectException(\InvalidArgumentException::class);
     $this->expectExceptionMessage($expected_exception_message);
-    $url = Database::getConnectionInfoAsUrl();
+    Database::getConnectionInfoAsUrl();
   }
 
   /**
@@ -476,7 +498,7 @@ class UrlConversionTest extends UnitTestCase {
    *     database, username, password, prefix, host, port, namespace and driver.
    *   - The expected exception message.
    */
-  public static function providerInvalidArgumentGetConnectionInfoAsUrl() {
+  public static function providerInvalidArgumentGetConnectionInfoAsUrl(): array {
     return [
       'Missing database key' => [
         [
@@ -490,23 +512,38 @@ class UrlConversionTest extends UnitTestCase {
   }
 
   /**
-   * @covers ::convertDbUrlToConnectionInfo
+   * Tests driver module does not exist.
+   *
+   * @legacy-covers ::convertDbUrlToConnectionInfo
    */
   public function testDriverModuleDoesNotExist(): void {
     $url = 'foo_bar_mysql://test_user:test_pass@test_host:3306/test_database?module=foo_bar';
     $this->expectException(UnknownExtensionException::class);
     $this->expectExceptionMessage("The database_driver Drupal\\foo_bar\\Driver\\Database\\foo_bar_mysql does not exist.");
-    Database::convertDbUrlToConnectionInfo($url, $this->root, TRUE);
+    Database::convertDbUrlToConnectionInfo($url, TRUE);
   }
 
   /**
-   * @covers ::convertDbUrlToConnectionInfo
+   * Tests module driver does not exist.
+   *
+   * @legacy-covers ::convertDbUrlToConnectionInfo
    */
   public function testModuleDriverDoesNotExist(): void {
     $url = 'driver_test_mysql://test_user:test_pass@test_host:3306/test_database?module=driver_test';
     $this->expectException(UnknownExtensionException::class);
     $this->expectExceptionMessage("The database_driver Drupal\\driver_test\\Driver\\Database\\driver_test_mysql does not exist.");
-    Database::convertDbUrlToConnectionInfo($url, $this->root, TRUE);
+    Database::convertDbUrlToConnectionInfo($url, TRUE);
+  }
+
+  /**
+   * Tests deprecation of root parameter.
+   *
+   * @legacy-covers ::convertDbUrlToConnectionInfo
+   */
+  #[IgnoreDeprecations]
+  public function testDeprecationOfRootParameter(): void {
+    $this->expectDeprecation('Passing a string $root value to Drupal\\Core\\Database\\Database::convertDbUrlToConnectionInfo() is deprecated in drupal:11.3.0 and will be removed in drupal:12.0.0. There is no replacement. See https://www.drupal.org/node/3511287');
+    Database::convertDbUrlToConnectionInfo('sqlite://localhost/test_database', $this->root, TRUE);
   }
 
 }
